==> mingw-w64-embree-3.13.5-2.src.tar.zst: embree-3.13.5/doc/src/api-ref.md <==
## rtcNewDevice
``` {include=src/api/rtcNewDevice.md}
```
\pagebreak

## rtcRetainDevice
``` {include=src/api/rtcRetainDevice.md}
```
\pagebreak

## rtcReleaseDevice
``` {include=src/api/rtcReleaseDevice.md}
```
\pagebreak

## rtcGetDeviceProperty
``` {include=src/api/rtcGetDeviceProperty.md}
```
\pagebreak

## rtcGetDeviceError
``` {include=src/api/rtcGetDeviceError.md}
```
\pagebreak

## rtcSetDeviceErrorFunction
``` {include=src/api/rtcSetDeviceErrorFunction.md}
```
\pagebreak

## rtcSetDeviceMemoryMonitorFunction
``` {include=src/api/rtcSetDeviceMemoryMonitorFunction.md}
```
\pagebreak

## rtcNewScene
``` {include=src/api/rtcNewScene.md}
```
\pagebreak

## rtcGetSceneDevice
``` {include=src/api/rtcGetSceneDevice.md}
```
\pagebreak

## rtcRetainScene
``` {include=src/api/rtcRetainScene.md}
```
\pagebreak

## rtcReleaseScene
``` {include=src/api/rtcReleaseScene.md}
```
\pagebreak

## rtcAttachGeometry
``` {include=src/api/rtcAttachGeometry.md}
```
\pagebreak

## rtcAttachGeometryByID
``` {include=src/api/rtcAttachGeometryByID.md}
```
\pagebreak

## rtcDetachGeometry
``` {include=src/api/rtcDetachGeometry.md}
```
\pagebreak

## rtcGetGeometry
``` {include=src/api/rtcGetGeometry.md}
```
\pagebreak

## rtcGetGeometryThreadSafe
``` {include=src/api/rtcGetGeometryThreadSafe.md}
```
\pagebreak

## rtcCommitScene
``` {include=src/api/rtcCommitScene.md}
```
\pagebreak

## rtcJoinCommitScene
``` {include=src/api/rtcJoinCommitScene.md}
```
\pagebreak

## rtcSetSceneProgressMonitorFunction
``` {include=src/api/rtcSetSceneProgressMonitorFunction.md}
```
\pagebreak

## rtcSetSceneBuildQuality
``` {include=src/api/rtcSetSceneBuildQuality.md}
```
\pagebreak

## rtcSetSceneFlags
``` {include=src/api/rtcSetSceneFlags.md}
```
\pagebreak

## rtcGetSceneFlags
``` {include=src/api/rtcGetSceneFlags.md}
```
\pagebreak


## rtcGetSceneBounds
``` {include=src/api/rtcGetSceneBounds.md}
```
\pagebreak

## rtcGetSceneLinearBounds
``` {include=src/api/rtcGetSceneLinearBounds.md}
```
\pagebreak

## rtcNewGeometry
``` {include=src/api/rtcNewGeometry.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_TRIANGLE
``` {include=src/api/RTC_GEOMETRY_TYPE_TRIANGLE.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_QUAD
``` {include=src/api/RTC_GEOMETRY_TYPE_QUAD.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_GRID
``` {include=src/api/RTC_GEOMETRY_TYPE_GRID.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_SUBDIVISION
``` {include=src/api/RTC_GEOMETRY_TYPE_SUBDIVISION.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_CURVE
``` {include=src/api/RTC_GEOMETRY_TYPE_CURVE.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_POINT
``` {include=src/api/RTC_GEOMETRY_TYPE_POINT.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_USER
``` {include=src/api/RTC_GEOMETRY_TYPE_USER.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_INSTANCE
``` {include=src/api/RTC_GEOMETRY_TYPE_INSTANCE.md}
```
\pagebreak

## RTCCurveFlags
``` {include=src/api/RTCCurveFlags.md}
```
\pagebreak

## rtcRetainGeometry
``` {include=src/api/rtcRetainGeometry.md}
```
\pagebreak

## rtcReleaseGeometry
``` {include=src/api/rtcReleaseGeometry.md}
```
\pagebreak

## rtcCommitGeometry
``` {include=src/api/rtcCommitGeometry.md}
```
\pagebreak

## rtcEnableGeometry
``` {include=src/api/rtcEnableGeometry.md}
```
\pagebreak

## rtcDisableGeometry
``` {include=src/api/rtcDisableGeometry.md}
```
\pagebreak

## rtcSetGeometryTimeStepCount
``` {include=src/api/rtcSetGeometryTimeStepCount.md}
```
\pagebreak

## rtcSetGeometryTimeRange
``` {include=src/api/rtcSetGeometryTimeRange.md}
```
\pagebreak

## rtcSetGeometryVertexAttributeCount
``` {include=src/api/rtcSetGeometryVertexAttributeCount.md}
```
\pagebreak

## rtcSetGeometryMask
``` {include=src/api/rtcSetGeometryMask.md}
```
\pagebreak

## rtcSetGeometryBuildQuality
``` {include=src/api/rtcSetGeometryBuildQuality.md}
```
\pagebreak

## rtcSetGeometryBuffer
``` {include=src/api/rtcSetGeometryBuffer.md}
```
\pagebreak

## rtcSetSharedGeometryBuffer
``` {include=src/api/rtcSetSharedGeometryBuffer.md}
```
\pagebreak

## rtcSetNewGeometryBuffer
``` {include=src/api/rtcSetNewGeometryBuffer.md}
```
\pagebreak

## RTCFormat
``` {include=src/api/RTCFormat.md}
```
\pagebreak

## RTCBufferType
``` {include=src/api/RTCBufferType.md}
```
\pagebreak

## rtcGetGeometryBufferData
``` {include=src/api/rtcGetGeometryBufferData.md}
```
\pagebreak

## rtcUpdateGeometryBuffer
``` {include=src/api/rtcUpdateGeometryBuffer.md}
```
\pagebreak

## rtcSetGeometryIntersectFilterFunction
``` {include=src/api/rtcSetGeometryIntersectFilterFunction.md}
```
\pagebreak

## rtcSetGeometryOccludedFilterFunction
``` {include=src/api/rtcSetGeometryOccludedFilterFunction.md}
```
\pagebreak

## rtcFilterIntersection
``` {include=src/api/rtcFilterIntersection.md}
```
\pagebreak

## rtcFilterOcclusion
``` {include=src/api/rtcFilterOcclusion.md}
```
\pagebreak

## rtcSetGeometryUserData
``` {include=src/api/rtcSetGeometryUserData.md}
```
\pagebreak

## rtcGetGeometryUserData
``` {include=src/api/rtcGetGeometryUserData.md}
```
\pagebreak


## rtcSetGeometryUserPrimitiveCount
``` {include=src/api/rtcSetGeometryUserPrimitiveCount.md}
```
\pagebreak

## rtcSetGeometryBoundsFunction
``` {include=src/api/rtcSetGeometryBoundsFunction.md}
```
\pagebreak

## rtcSetGeometryIntersectFunction
``` {include=src/api/rtcSetGeometryIntersectFunction.md}
```
\pagebreak

## rtcSetGeometryOccludedFunction
``` {include=src/api/rtcSetGeometryOccludedFunction.md}
```
\pagebreak

## rtcSetGeometryPointQueryFunction
``` {include=src/api/rtcSetGeometryPointQueryFunction.md}
```
\pagebreak

## rtcSetGeometryInstancedScene
``` {include=src/api/rtcSetGeometryInstancedScene.md}
```
\pagebreak

## rtcSetGeometryTransform
``` {include=src/api/rtcSetGeometryTransform.md}
```
\pagebreak

## rtcSetGeometryTransformQuaternion
``` {include=src/api/rtcSetGeometryTransformQuaternion.md}
```
\pagebreak

## rtcGetGeometryTransform
``` {include=src/api/rtcGetGeometryTransform.md}
```
\pagebreak


## rtcSetGeometryTessellationRate
``` {include=src/api/rtcSetGeometryTessellationRate.md}
```
\pagebreak

## rtcSetGeometryTopologyCount
``` {include=src/api/rtcSetGeometryTopologyCount.md}
```
\pagebreak

## rtcSetGeometrySubdivisionMode
``` {include=src/api/rtcSetGeometrySubdivisionMode.md}
```
\pagebreak

## rtcSetGeometryVertexAttributeTopology
``` {include=src/api/rtcSetGeometryVertexAttributeTopology.md}
```
\pagebreak

## rtcSetGeometryDisplacementFunction
``` {include=src/api/rtcSetGeometryDisplacementFunction.md}
```
\pagebreak

## rtcGetGeometryFirstHalfEdge
``` {include=src/api/rtcGetGeometryFirstHalfEdge.md}
```
\pagebreak

## rtcGetGeometryFace
``` {include=src/api/rtcGetGeometryFace.md}
```
\pagebreak

## rtcGetGeometryNextHalfEdge
``` {include=src/api/rtcGetGeometryNextHalfEdge.md}
```
\pagebreak

## rtcGetGeometryPreviousHalfEdge
``` {include=src/api/rtcGetGeometryPreviousHalfEdge.md}
```
\pagebreak

## rtcGetGeometryOppositeHalfEdge
``` {include=src/api/rtcGetGeometryOppositeHalfEdge.md}
```
\pagebreak

## rtcInterpolate
``` {include=src/api/rtcInterpolate.md}
```
\pagebreak

## rtcInterpolateN
``` {include=src/api/rtcInterpolateN.md}
```
\pagebreak


## rtcNewBuffer
``` {include=src/api/rtcNewBuffer.md}
```
\pagebreak

## rtcNewSharedBuffer
``` {include=src/api/rtcNewSharedBuffer.md}
```
\pagebreak

## rtcRetainBuffer
``` {include=src/api/rtcRetainBuffer.md}
```
\pagebreak

## rtcReleaseBuffer
``` {include=src/api/rtcReleaseBuffer.md}
```
\pagebreak

## rtcGetBufferData
``` {include=src/api/rtcGetBufferData.md}
```
\pagebreak

## RTCRay
``` {include=src/api/RTCRay.md}
```
\pagebreak

## RTCHit
``` {include=src/api/RTCHit.md}
```
\pagebreak

## RTCRayHit
``` {include=src/api/RTCRayHit.md}
```
\pagebreak

## RTCRayN
``` {include=src/api/RTCRayN.md}
```
\pagebreak

## RTCHitN
``` {include=src/api/RTCHitN.md}
```
\pagebreak

## RTCRayHitN
``` {include=src/api/RTCRayHitN.md}
```
\pagebreak

## rtcInitIntersectContext
``` {include=src/api/rtcInitIntersectContext.md}
```
\pagebreak

## rtcIntersect1
``` {include=src/api/rtcIntersect1.md}
```
\pagebreak

## rtcOccluded1
``` {include=src/api/rtcOccluded1.md}
```
\pagebreak

## rtcIntersect4/8/16
``` {include=src/api/rtcIntersect4.md}
```
\pagebreak

## rtcOccluded4/8/16
``` {include=src/api/rtcOccluded4.md}
```
\pagebreak

## rtcIntersect1M
``` {include=src/api/rtcIntersect1M.md}
```
\pagebreak

## rtcOccluded1M
``` {include=src/api/rtcOccluded1M.md}
```
\pagebreak

## rtcIntersect1Mp
``` {include=src/api/rtcIntersect1Mp.md}
```
\pagebreak

## rtcOccluded1Mp
``` {include=src/api/rtcOccluded1Mp.md}
```
\pagebreak

## rtcIntersectNM
``` {include=src/api/rtcIntersectNM.md}
```
\pagebreak

## rtcOccludedNM
``` {include=src/api/rtcOccludedNM.md}
```
\pagebreak

## rtcIntersectNp
``` {include=src/api/rtcIntersectNp.md}
```
\pagebreak

## rtcOccludedNp
``` {include=src/api/rtcOccludedNp.md}
```
\pagebreak

## rtcInitPointQueryContext
``` {include=src/api/rtcInitPointQueryContext.md}
```
\pagebreak

## rtcPointQuery
``` {include=src/api/rtcPointQuery.md}
```
\pagebreak

## rtcCollide
``` {include=src/api/rtcCollide.md}
```
\pagebreak

## rtcNewBVH
``` {include=src/api/rtcNewBVH.md}
```
\pagebreak

## rtcRetainBVH
``` {include=src/api/rtcRetainBVH.md}
```
\pagebreak

## rtcReleaseBVH
``` {include=src/api/rtcReleaseBVH.md}
```
\pagebreak

## rtcBuildBVH
``` {include=src/api/rtcBuildBVH.md}
```
\pagebreak

## RTCQuaternionDecomposition
``` {include=src/api/RTCQuaternionDecomposition.md}
```
\pagebreak

## rtcInitQuaternionDecomposition
``` {include=src/api/rtcInitQuaternionDecomposition.md}
```
\pagebreak

==> mingw-w64-embree-4.3.1-1.src.tar.zst: embree-4.3.1/doc/src/api-ref.md <==
## rtcNewDevice
``` {include=src/api/rtcNewDevice.md}
```
\pagebreak

## rtcNewSYCLDevice
``` {include=src/api/rtcNewSYCLDevice.md}
```
\pagebreak

## rtcIsSYCLDeviceSupported
``` {include=src/api/rtcIsSYCLDeviceSupported.md}
```
\pagebreak

## rtcSYCLDeviceSelector
``` {include=src/api/rtcSYCLDeviceSelector.md}
```
\pagebreak

## rtcSetDeviceSYCLDevice
``` {include=src/api/rtcSetDeviceSYCLDevice.md}
```
\pagebreak

## rtcRetainDevice
``` {include=src/api/rtcRetainDevice.md}
```
\pagebreak

## rtcReleaseDevice
``` {include=src/api/rtcReleaseDevice.md}
```
\pagebreak

## rtcGetDeviceProperty
``` {include=src/api/rtcGetDeviceProperty.md}
```
\pagebreak

## rtcGetDeviceError
``` {include=src/api/rtcGetDeviceError.md}
```
\pagebreak

## rtcSetDeviceErrorFunction
``` {include=src/api/rtcSetDeviceErrorFunction.md}
```
\pagebreak

## rtcSetDeviceMemoryMonitorFunction
``` {include=src/api/rtcSetDeviceMemoryMonitorFunction.md}
```
\pagebreak

## rtcNewScene
``` {include=src/api/rtcNewScene.md}
```
\pagebreak

## rtcGetSceneDevice
``` {include=src/api/rtcGetSceneDevice.md}
```
\pagebreak

## rtcRetainScene
``` {include=src/api/rtcRetainScene.md}
```
\pagebreak

## rtcReleaseScene
``` {include=src/api/rtcReleaseScene.md}
```
\pagebreak

## rtcAttachGeometry
``` {include=src/api/rtcAttachGeometry.md}
```
\pagebreak

## rtcAttachGeometryByID
``` {include=src/api/rtcAttachGeometryByID.md}
```
\pagebreak

## rtcDetachGeometry
``` {include=src/api/rtcDetachGeometry.md}
```
\pagebreak

## rtcGetGeometry
``` {include=src/api/rtcGetGeometry.md}
```
\pagebreak

## rtcGetGeometryThreadSafe
``` {include=src/api/rtcGetGeometryThreadSafe.md}
```
\pagebreak

## rtcCommitScene
``` {include=src/api/rtcCommitScene.md}
```
\pagebreak

## rtcJoinCommitScene
``` {include=src/api/rtcJoinCommitScene.md}
```
\pagebreak

## rtcSetSceneProgressMonitorFunction
``` {include=src/api/rtcSetSceneProgressMonitorFunction.md}
```
\pagebreak

## rtcSetSceneBuildQuality
``` {include=src/api/rtcSetSceneBuildQuality.md}
```
\pagebreak

## rtcSetSceneFlags
``` {include=src/api/rtcSetSceneFlags.md}
```
\pagebreak

## rtcGetSceneFlags
``` {include=src/api/rtcGetSceneFlags.md}
```
\pagebreak


## rtcGetSceneBounds
``` {include=src/api/rtcGetSceneBounds.md}
```
\pagebreak

## rtcGetSceneLinearBounds
``` {include=src/api/rtcGetSceneLinearBounds.md}
```
\pagebreak

## rtcNewGeometry
``` {include=src/api/rtcNewGeometry.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_TRIANGLE
``` {include=src/api/RTC_GEOMETRY_TYPE_TRIANGLE.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_QUAD
``` {include=src/api/RTC_GEOMETRY_TYPE_QUAD.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_GRID
``` {include=src/api/RTC_GEOMETRY_TYPE_GRID.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_SUBDIVISION
``` {include=src/api/RTC_GEOMETRY_TYPE_SUBDIVISION.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_CURVE
``` {include=src/api/RTC_GEOMETRY_TYPE_CURVE.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_POINT
``` {include=src/api/RTC_GEOMETRY_TYPE_POINT.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_USER
``` {include=src/api/RTC_GEOMETRY_TYPE_USER.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_INSTANCE
``` {include=src/api/RTC_GEOMETRY_TYPE_INSTANCE.md}
```
\pagebreak

## RTC_GEOMETRY_TYPE_INSTANCE_ARRAY
``` {include=src/api/RTC_GEOMETRY_TYPE_INSTANCE_ARRAY.md}
```
\pagebreak

## RTCCurveFlags
``` {include=src/api/RTCCurveFlags.md}
```
\pagebreak

## rtcRetainGeometry
``` {include=src/api/rtcRetainGeometry.md}
```
\pagebreak

## rtcReleaseGeometry
``` {include=src/api/rtcReleaseGeometry.md}
```
\pagebreak

## rtcCommitGeometry
``` {include=src/api/rtcCommitGeometry.md}
```
\pagebreak

## rtcEnableGeometry
``` {include=src/api/rtcEnableGeometry.md}
```
\pagebreak

## rtcDisableGeometry
``` {include=src/api/rtcDisableGeometry.md}
```
\pagebreak

## rtcSetGeometryTimeStepCount
``` {include=src/api/rtcSetGeometryTimeStepCount.md}
```
\pagebreak

## rtcSetGeometryTimeRange
``` {include=src/api/rtcSetGeometryTimeRange.md}
```
\pagebreak

## rtcSetGeometryVertexAttributeCount
``` {include=src/api/rtcSetGeometryVertexAttributeCount.md}
```
\pagebreak

## rtcSetGeometryMask
``` {include=src/api/rtcSetGeometryMask.md}
```
\pagebreak

## rtcSetGeometryBuildQuality
``` {include=src/api/rtcSetGeometryBuildQuality.md}
```
\pagebreak

## rtcSetGeometryMaxRadiusScale
``` {include=src/api/rtcSetGeometryMaxRadiusScale.md}
```
\pagebreak

## rtcSetGeometryBuffer
``` {include=src/api/rtcSetGeometryBuffer.md}
```
\pagebreak

## rtcSetSharedGeometryBuffer
``` {include=src/api/rtcSetSharedGeometryBuffer.md}
```
\pagebreak

## rtcSetNewGeometryBuffer
``` {include=src/api/rtcSetNewGeometryBuffer.md}
```
\pagebreak

## RTCFormat
``` {include=src/api/RTCFormat.md}
```
\pagebreak

## RTCBufferType
``` {include=src/api/RTCBufferType.md}
```
\pagebreak

## rtcGetGeometryBufferData
``` {include=src/api/rtcGetGeometryBufferData.md}
```
\pagebreak

## rtcUpdateGeometryBuffer
``` {include=src/api/rtcUpdateGeometryBuffer.md}
```
\pagebreak

## rtcSetGeometryIntersectFilterFunction
``` {include=src/api/rtcSetGeometryIntersectFilterFunction.md}
```
\pagebreak

## rtcSetGeometryOccludedFilterFunction
``` {include=src/api/rtcSetGeometryOccludedFilterFunction.md}
```
\pagebreak

## rtcSetGeometryEnableFilterFunctionFromArguments
``` {include=src/api/rtcSetGeometryEnableFilterFunctionFromArguments.md}
```
\pagebreak

## rtcInvokeIntersectFilterFromGeometry
``` {include=src/api/rtcInvokeIntersectFilterFromGeometry.md}
```
\pagebreak

## rtcInvokeOccludedFilterFromGeometry
``` {include=src/api/rtcInvokeOccludedFilterFromGeometry.md}
```
\pagebreak

## rtcSetGeometryUserData
``` {include=src/api/rtcSetGeometryUserData.md}
```
\pagebreak

## rtcGetGeometryUserData
``` {include=src/api/rtcGetGeometryUserData.md}
```
\pagebreak

## rtcGetGeometryUserDataFromScene
``` {include=src/api/rtcGetGeometryUserDataFromScene.md}
```
\pagebreak

## rtcSetGeometryUserPrimitiveCount
``` {include=src/api/rtcSetGeometryUserPrimitiveCount.md}
```
\pagebreak

## rtcSetGeometryBoundsFunction
``` {include=src/api/rtcSetGeometryBoundsFunction.md}
```
\pagebreak

## rtcSetGeometryIntersectFunction
``` {include=src/api/rtcSetGeometryIntersectFunction.md}
```
\pagebreak

## rtcSetGeometryOccludedFunction
``` {include=src/api/rtcSetGeometryOccludedFunction.md}
```
\pagebreak

## rtcSetGeometryPointQueryFunction
``` {include=src/api/rtcSetGeometryPointQueryFunction.md}
```
\pagebreak

## rtcGetSYCLDeviceFunctionPointer
``` {include=src/api/rtcGetSYCLDeviceFunctionPointer.md}
```
\pagebreak


## rtcSetGeometryInstancedScene
``` {include=src/api/rtcSetGeometryInstancedScene.md}
```
\pagebreak

## rtcSetGeometryInstancedScenes
``` {include=src/api/rtcSetGeometryInstancedScenes.md}
```
\pagebreak

## rtcSetGeometryTransform
``` {include=src/api/rtcSetGeometryTransform.md}
```
\pagebreak

## rtcSetGeometryTransformQuaternion
``` {include=src/api/rtcSetGeometryTransformQuaternion.md}
```
\pagebreak

## rtcGetGeometryTransform
``` {include=src/api/rtcGetGeometryTransform.md}
```
\pagebreak

## rtcGetGeometryTransformEx
``` {include=src/api/rtcGetGeometryTransformEx.md}
```
\pagebreak

## rtcGetGeometryTransformFromScene
``` {include=src/api/rtcGetGeometryTransformFromScene.md}
```
\pagebreak

## rtcSetGeometryTessellationRate
``` {include=src/api/rtcSetGeometryTessellationRate.md}
```
\pagebreak

## rtcSetGeometryTopologyCount
``` {include=src/api/rtcSetGeometryTopologyCount.md}
```
\pagebreak

## rtcSetGeometrySubdivisionMode
``` {include=src/api/rtcSetGeometrySubdivisionMode.md}
```
\pagebreak

## rtcSetGeometryVertexAttributeTopology
``` {include=src/api/rtcSetGeometryVertexAttributeTopology.md}
```
\pagebreak

## rtcSetGeometryDisplacementFunction
``` {include=src/api/rtcSetGeometryDisplacementFunction.md}
```
\pagebreak

## rtcGetGeometryFirstHalfEdge
``` {include=src/api/rtcGetGeometryFirstHalfEdge.md}
```
\pagebreak

## rtcGetGeometryFace
``` {include=src/api/rtcGetGeometryFace.md}
```
\pagebreak

## rtcGetGeometryNextHalfEdge
``` {include=src/api/rtcGetGeometryNextHalfEdge.md}
```
\pagebreak

## rtcGetGeometryPreviousHalfEdge
``` {include=src/api/rtcGetGeometryPreviousHalfEdge.md}
```
\pagebreak

## rtcGetGeometryOppositeHalfEdge
``` {include=src/api/rtcGetGeometryOppositeHalfEdge.md}
```
\pagebreak

## rtcInterpolate
``` {include=src/api/rtcInterpolate.md}
```
\pagebreak

## rtcInterpolateN
``` {include=src/api/rtcInterpolateN.md}
```
\pagebreak


## rtcNewBuffer
``` {include=src/api/rtcNewBuffer.md}
```
\pagebreak

## rtcNewSharedBuffer
``` {include=src/api/rtcNewSharedBuffer.md}
```
\pagebreak

## rtcRetainBuffer
``` {include=src/api/rtcRetainBuffer.md}
```
\pagebreak

## rtcReleaseBuffer
``` {include=src/api/rtcReleaseBuffer.md}
```
\pagebreak

## rtcGetBufferData
``` {include=src/api/rtcGetBufferData.md}
```
\pagebreak

## RTCRay
``` {include=src/api/RTCRay.md}
```
\pagebreak

## RTCHit
``` {include=src/api/RTCHit.md}
```
\pagebreak

## RTCRayHit
``` {include=src/api/RTCRayHit.md}
```
\pagebreak

## RTCRayN
``` {include=src/api/RTCRayN.md}
```
\pagebreak

## RTCHitN
``` {include=src/api/RTCHitN.md}
```
\pagebreak

## RTCRayHitN
``` {include=src/api/RTCRayHitN.md}
```
\pagebreak

## RTCFeatureFlags
``` {include=src/api/RTCFeatureFlags.md}
```
\pagebreak

## rtcInitIntersectArguments
``` {include=src/api/rtcInitIntersectArguments.md}
```
\pagebreak

## rtcInitOccludedArguments
``` {include=src/api/rtcInitOccludedArguments.md}
```
\pagebreak

## rtcInitRayQueryContext
``` {include=src/api/rtcInitRayQueryContext.md}
```
\pagebreak

## rtcIntersect1
``` {include=src/api/rtcIntersect1.md}
```
\pagebreak

## rtcOccluded1
``` {include=src/api/rtcOccluded1.md}
```
\pagebreak

## rtcIntersect4/8/16
``` {include=src/api/rtcIntersect4.md}
```
\pagebreak

## rtcOccluded4/8/16
``` {include=src/api/rtcOccluded4.md}
```
\pagebreak

## rtcForwardIntersect1
``` {include=src/api/rtcForwardIntersect1.md}
```
\pagebreak

## rtcForwardOccluded1
``` {include=src/api/rtcForwardOccluded1.md}
```
\pagebreak

## rtcForwardIntersect4/8/16
``` {include=src/api/rtcForwardIntersect4.md}
```
\pagebreak

## rtcForwardOccluded4/8/16
``` {include=src/api/rtcForwardOccluded4.md}
```
\pagebreak

## rtcInitPointQueryContext
``` {include=src/api/rtcInitPointQueryContext.md}
```
\pagebreak

## rtcPointQuery
``` {include=src/api/rtcPointQuery.md}
```
\pagebreak

## rtcCollide
``` {include=src/api/rtcCollide.md}
```
\pagebreak

## rtcNewBVH
``` {include=src/api/rtcNewBVH.md}
```
\pagebreak

## rtcRetainBVH
``` {include=src/api/rtcRetainBVH.md}
```
\pagebreak

## rtcReleaseBVH
``` {include=src/api/rtcReleaseBVH.md}
```
\pagebreak

## rtcBuildBVH
``` {include=src/api/rtcBuildBVH.md}
```
\pagebreak

## RTCQuaternionDecomposition
``` {include=src/api/RTCQuaternionDecomposition.md}
```
\pagebreak

## rtcInitQuaternionDecomposition
``` {include=src/api/rtcInitQuaternionDecomposition.md}
```
\pagebreak
